@@ -3,48 +3,84 @@ package YAML::Yuyu;
 use strict;
 use warnings;
 
+use Carp;
 
 =head1 NAME
 
-    YAML::Yuyu - Clase para hacer presentaciones fcilmente a partir de un fichero YAML
+    YAML::Yuyu - Easily create presentations from a YAML file.
 
 =head1 SYNOPSIS
 
-    my $yuyu = new YAML::Yuyu( { path => $path, 
+    my $yuyu = new YAML::Yuyu( path => $path, 
                                  plantilla => 'plantilla.tmpl',
-                                 contenido => 'contenido.yaml',
-                                 staticdir => `pwd`
-                                  } );
+                                 contenido => 'contenido.yaml' ); 
+
+    # From an array of pre-loaded or programatically created slides 
+    use YAML qw(LoadFile);
+    @slides = LoadFile('yourslides.yaml');
+    my $yuyu = new YAML::Yuyu( path => $path, 
+                               plantilla => 'plantilla.tmpl',
+                               contenido => \@slides  ); 
+    
+    # From a glob; v. gr. data behind the __END__ marker
+    my $yuyu3 = YAML::Yuyu->new( path => $path, 
+			         plantilla => $plantilla, 
+			         contenido => \*main::DATA );
+
+    my $nth_slide = $yuyu->slide( $n ); 
+    my $front_page = $yuyu->portada();
+    my $index = $yuyu->index();
+
+=cut
 
 =head1 DESCRIPTION
 
-Clase base que contiene la conexin a la base de datos y otros objetos
-tales como el generador de claves. 
+Derived from L<Object::props>, which is a way cool module, this module
+loads a YAML from which it derives a presentation: index, slides, and
+so on. It can be used from another module, but you'll usually want to
+do it from the scripts for standalone presentations (with its own web
+server, no less) or to generate a single or several HTML pages you'll
+want to present from somewhere else or upload to a website.
 
 =head1 USAGE
 
-  bash$ yuyupress presentation.yaml [path-to-templates] [template(s)]
+Stand-alone presentation tool. It will use default templates, if none
+is indicated 
+
+    bash$ yuyupress presentation.yaml [path-to-templates] [template(s)] 
+
+Generate a web page with the presentation
+
+    bash$ yuyugen presentation.yaml [path-to-templates] [template(s)]
 
 =head1 METHODS
 
 =cut
 
-package YAML::Yuyu;
-
-use YAML qw(LoadFile); #Para configuracin
+use YAML qw(LoadFile Load); # Para configuracin
 use Template;
 use Exporter;
 
-our ($VERSION) = ( '$Revision: 1.9 $' =~ /(\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 1.14 $' =~ /(\d+\.\d+)/ ) ;
 
 #Declaracin de propiedades
-use Object::props qw( path plantilla contenido staticdir );
+use Object::props qw( path plantilla contenido );
 
 use Class::constr { 
   init => sub { 
     my $template = Template->new( {INCLUDE_PATH => $_[0]->path } );
     $_[0]->{_template} = $template;
-    my @stream =  LoadFile( $_[0]->contenido );
+    my @stream;
+    if ( ref $_[0]->contenido eq '' ) {
+      @stream =  LoadFile( $_[0]->contenido );
+    } elsif ( ref $_[0]->contenido eq 'ARRAY' ) {
+      @stream = @{$_[0]->contenido};
+    } elsif ( ref $_[0]->contenido eq 'GLOB' ) {
+      my $glob = $_[0]->contenido;
+      my $stream = join('',<$glob>);
+      @stream = Load($stream);
+    }
+    carp "Bad content stream" if !@stream;
     $_[0]->{_portada} = shift @stream;
     $_[0]->{_slides} = \@stream;
     $_[0]->{_doc} = $_[0]->plantilla;
@@ -52,6 +88,12 @@ use Class::constr {
   }
 };
 
+=head2 portada
+
+C<portada> is the main page; it returns the title and general front matter for the presentation
+
+=cut
+
 sub portada {
   my $self = shift;
   my %data = %{$self->{_portada}->[0]};
@@ -73,6 +115,13 @@ EIF
   return $salida;
 }
 
+
+=head2 slide
+
+C<slide>( $slide_number) returns the $slide_number'th slide from the presentation
+
+=cut
+
 sub slide {
   my $self = shift;
   my $nr = shift || 0;
@@ -101,6 +150,12 @@ sub slide {
   return $salida;
 };
 
+=head2 indice
+
+Returns the presentation index
+
+=cut
+
 sub indice {
   my $self = shift;
   my $i;
@@ -181,4 +236,17 @@ sub procesaItem {
   return $contenido;
 }
 
+=head1 Copyright
+
+  This file is released under the GPL. See the LICENSE file included in this distribution,
+  or go to http://www.fsf.org/licenses/gpl.txt
+
+  CVS Info: $Date: 2008/02/11 09:33:19 $
+  $Header: /home/jmerelo/repos/yuyupress/lib/YAML/Yuyu.pm,v 1.14 2008/02/11 09:33:19 jmerelo Exp $
+  $Author: jmerelo $
+  $Revision: 1.14 $
+
+=cut
+
+
 'Sacab';
